.. role:: hidden
    :class: hidden-section

ax.plot
=======

.. automodule:: ax.plot
.. currentmodule:: ax.plot


Rendering
---------

.. automodule:: ax.plot.render
    :members:
    :undoc-members:
    :show-inheritance:


Plots
-----

Base
~~~~

.. automodule:: ax.plot.base
    :members:
    :undoc-members:
    :show-inheritance:

Bandit Rollout
~~~~~~~~~~~~~~
.. automodule:: ax.plot.bandit_rollout
    :members:
    :undoc-members:
    :show-inheritance:

Contour Plot
~~~~~~~~~~~~

.. automodule:: ax.plot.contour
    :members:
    :undoc-members:
    :show-inheritance:

Feature Importances
~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.plot.feature_importances
    :members:
    :undoc-members:
    :show-inheritance:

Marginal Effects
~~~~~~~~~~~~~~~~

.. automodule:: ax.plot.marginal_effects
    :members:
    :undoc-members:
    :show-inheritance:

Model Diagnostics
~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.plot.diagnostic
    :members:
    :undoc-members:
    :show-inheritance:

Pareto Plots
~~~~~~~~~~~~
.. automodule:: ax.plot.pareto_frontier
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: ax.plot.pareto_utils
    :members:
    :undoc-members:
    :show-inheritance:

Scatter Plots
~~~~~~~~~~~~~

.. automodule:: ax.plot.scatter
    :members:
    :undoc-members:
    :show-inheritance:

Slice Plot
~~~~~~~~~~

.. automodule:: ax.plot.slice
    :members:
    :undoc-members:
    :show-inheritance:

Table
~~~~~

.. automodule:: ax.plot.table_view
    :members:
    :undoc-members:
    :show-inheritance:

Trace Plots
~~~~~~~~~~~

.. automodule:: ax.plot.trace
    :members:
    :undoc-members:
    :show-inheritance:

Parallel Coordinates
~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.plot.parallel_coordinates
    :members:
    :undoc-members:
    :show-inheritance:

Plotting Utilities
------------------

.. automodule:: ax.plot.color
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: ax.plot.helper
    :members:
    :undoc-members:
    :show-inheritance:
